.. confattr documentation master file, created by
   sphinx-quickstart on Sun Nov 20 08:25:23 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Introduction and examples
=========================

.. toctree::
   :maxdepth: 2

   intro


Reference
=========

.. toctree::
   :maxdepth: 2

   confattr
   confattr.config
   confattr.configfile
   confattr.subprocess_pipe
   confattr.types


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
